@@ -7,72 +7,72 @@ import logging
 import logging.handlers
 import itertools
 # import os
-import seaborn as sns
+# import seaborn as sns
 from scipy.special import kv
 from scipy.optimize import broyden2, newton_krylov
 from scipy.optimize.nonlin import NoConvergence
 from io import StringIO
 import re
 from pathlib import Path
+from time import time_ns
 
 # import warnings
 
 # logging
 # see https://docs.python.org/3.7/howto/logging.html
 # and https://docs.python.org/3.7/howto/logging-cookbook.html
-# LOGFILE = os.path.join(os.path.split(__file__)[0], 'aggregate.log')
 LOGFILE = Path.home() / '.agglog/agg.main.logger.log'
-# RLOGFILE = Path.home() / '.agglog/r.agg.main.logger.log'
-# check it exists
 LOGFILE.parent.mkdir(exist_ok=True, parents=True)
 
 # approved method is call (__name__)
 logger = logging.getLogger('aggregate')
-logger.setLevel(logging.INFO)
+logger.setLevel(logging.DEBUG)
 
-# rh = logging.handlers.RotatingFileHandler(RLOGFILE, maxBytes=100000, backupCount=10)
-rh = logging.FileHandler(LOGFILE)
-rh.setLevel(logging.INFO)
-rh_formatter = logging.Formatter(
-    '%(asctime)s | %(name)s | %(levelname)-10s | %(funcName)s (l. %(lineno) 5d) | %(message)s')
-rh.setFormatter(rh_formatter)
+if len(logger.handlers) == 0:
+    # otherwise they proliferate whenever module is loaded...
+    rh = logging.FileHandler(LOGFILE, 'w', 'utf-8')
+    rh.setLevel(logging.DEBUG)
+    rh_formatter = logging.Formatter(
+        '%(asctime)s | %(name)s | %(levelname)-10s | %(funcName)-20s (l. %(lineno) 5d) | %(message)s')
+    rh.setFormatter(rh_formatter)
 
-# to stderr
-ch = logging.StreamHandler()
-ch.setLevel(logging.WARNING)
-ch_formatter = logging.Formatter(
-    '%(asctime)s | %(name)s | %(levelname)-10s | %(funcName)s (l. %(lineno) 5d) | %(message)s')
-ch.setFormatter(ch_formatter)
+    # to stderr
+    ch = logging.StreamHandler()
+    ch.setLevel(logging.INFO)
+    ch_formatter = logging.Formatter(
+        '%(levelname)-10s | %(funcName)-12s: %(message)s')
+    ch.setFormatter(ch_formatter)
+        # '%(name)s | %(levelname)-10s | %(funcName)-20s (l. %(lineno) 5d) | %(message)s')
 
-# add loggers
-logger.addHandler(rh)
-logger.addHandler(ch)
+    # add loggers
+    logger.addHandler(rh)
+    logger.addHandler(ch)
 
-# dev logger to stderr - all levels
-# used for messages during development
-# dev_logger = logging.getLogger('aggdev')
-# dev_logger.setLevel(logging.DEBUG)
-# sh = logging.StreamHandler()
-# sh_formatter = logging.Formatter(
-#     '%(asctime)s | %(name)s | %(levelname)-10s | %(funcName)s (l. %(lineno)d) | %(message)s')
-# sh.setFormatter(sh_formatter)
-# dev_logger.addHandler(sh)
-
-logger.info('aggregate_project.__init__ | New Aggregate Session started')
+# kick off message
+logger.debug('aggregate_project.__init__ | New Aggregate Session started')
 
 
-# display
-# def qd(df, max_rows=10):
-#     """
-#     generic quick display of data frame df
-#     aware of likely column names with appropriate format
-#     for each
-#     """
-#     if max_rows == -1:
-#         max_rows = df.shape[0]
-#         if max_rows > 1000:
-#             max_rows = 1000
-#     display(df.head(max_rows).style.format(get_fmts(df)))
+last_time = first_time = 0
+timer_active = False
+
+def start_timer():
+    global last_time, first_time, timer_active
+    last_time = time_ns()
+    first_time = last_time
+    timer_active = True
+
+
+def report_time(msg):
+    global last_time, timer_active
+    if timer_active:
+        t = time_ns()
+        logger.log(logging.INFO+1, f'{(t - last_time)/1e9:.6f} | {(t - first_time)/1e9:10.6f} | {msg}')
+        last_time = t
+
+
+def stop_timer():
+    global timer_active
+    timer_active = False
 
 
 def get_fmts(df):
@@ -403,7 +403,7 @@ class AxisManager(object):
 
     # methods for a more hands on approach
     @staticmethod
-    def good_grid(n):
+    def good_grid(n, c=4):
         """
         Good layout for n plots
         :param n:
@@ -416,7 +416,6 @@ class AxisManager(object):
         if n <= 20:
             r, c = basic[n]
         else:
-            c = 4
             r = n // c
             if r * c < n:
                 r += 1
@@ -629,7 +628,8 @@ class MomentAggregator(object):
 
     Internal variables agg, sev, frqe, tot = running total, 1, 2, 3 = noncentral moments, E(X^k)
 
-    :param freq_moms: function of one variable returning first three noncentral moments of the underlying frequency distribution
+    :param freq_moms: function of one variable returning first three noncentral moments of the underlying
+            frequency distribution
 
     """
     __slots__ = ['freq_1', 'freq_2', 'freq_3', 'sev_1', 'sev_2', 'sev_3', 'agg_1', 'agg_2', 'agg_3',
@@ -1380,8 +1380,10 @@ def frequency_examples(n, ν, f, κ, sichel_case, log2, xmax=500, **kwds):
                  ['poisson', 'delaporte', 'shifted_pig', 'sichel'],
                  ]:
         # keep the same colors
-        pal = [sns.color_palette("Paired", 7)[i] for i in [all_dist.index(j) for j in vars]]
-        df[vars].plot(kind='line', ax=next(axiter), color=pal)
+        # FIX TODO
+        print('FIX palette')
+        # pal = [sns.color_palette("Paired", 7)[i] for i in [all_dist.index(j) for j in vars]]
+        df[vars].plot(kind='line', ax=next(axiter)) #, color=pal)
         axiter.ax.set_xlim(0, 4 * n)
         df[vars].plot(kind='line', logy=True, ax=next(axiter), legend=None, color=pal)
     axiter.tidy()
@@ -1462,4 +1464,4 @@ def subsets(x):
     all non empty subsets of x, an interable
     """
     return list(itertools.chain.from_iterable(
-        itertools.combinations(x, n) for n in range(len(x) + 1)))[1:]
\ No newline at end of file
+        itertools.combinations(x, n) for n in range(len(x) + 1)))[1:]
